@@ -2,7 +2,8 @@
 # encoding: utf-8
 
 """
-Phantom
+Ghost
+
 Tool for encryption and decryption.
 Contains various functions and possibilities
 for creating an encrypted network stream and for
@@ -16,4 +17,4 @@ from .key import Key
 from .encryption import *
 from .stream import *
 
-__version__ = "1.0.0"
+__version__ = "1.0.1"
